@@ -1,4 +1,19 @@
-/*
+/*  Copyright 1997,2000-2002,2009 Alain Knaff.
+ *  This file is part of mtools.
+ *
+ *  Mtools is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Mtools is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with Mtools.  If not, see <http://www.gnu.org/licenses/>.
+ *
  * mdu.c:
  * Display the space occupied by an MSDOS directory
  */
@@ -24,13 +39,14 @@ typedef struct Arg_t {
 	MainParam_t mp;
 } Arg_t;
 
-static void usage(void)
+static void usage(int ret) NORETURN;
+static void usage(int ret)
 {
 		fprintf(stderr, "Mtools version %s, dated %s\n",
 			mversion, mdate);
 		fprintf(stderr, "Usage: %s: msdosdirectory\n",
 			progname);
-		exit(1);
+		exit(ret);
 }
 
 static int file_mdu(direntry_t *entry, MainParam_t *mp)
@@ -85,25 +101,32 @@ void mdu(int argc, char **argv, int type)
 	arg.all = 0;
 	arg.inDir = 0;
 	arg.summary = 0;
-	while ((c = getopt(argc, argv, "as")) != EOF) {
+	if(helpFlag(argc, argv))
+		usage(0);
+	while ((c = getopt(argc, argv, "i:ash")) != EOF) {
 		switch (c) {
+			case 'i':
+				set_cmd_line_image(optarg, 0);
+				break;
 			case 'a':
 				arg.all = 1;
 				break;
 			case 's':
 				arg.summary = 1;
 				break;
+			case 'h':
+				usage(0);
 			case '?':
-				usage();
+				usage(1);
 		}
 	}
 
 	if (optind >= argc)
-		usage();
+		usage(1);
 
 	if(arg.summary && arg.all) {
 		fprintf(stderr,"-a and -s options are mutually exclusive\n");
-		usage();
+		usage(1);
 	}
 
 	init_mp(&arg.mp);
